#
# spec file for package grafx2
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           grafx2
Version:        2.8.3124
Release:        1.14
Summary:        Pixel Art editor
License:        GPL-2.0-only
Group:          Productivity/Graphics/Bitmap Editors
URL:            http://grafx2.tk
Source:         https://gitlab.com/GrafX2/grafX2/-/jobs/2038210751/artifacts/raw/grafx2-%{version}-src.tgz
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libpng16-devel
BuildRequires:  libtiff-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL_image)
BuildRequires:  pkgconfig(SDL_ttf)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(lua)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(zlib)

%description
GrafX2 is a bitmap paint program inspired by the Amiga programs Deluxe Paint and Brilliance.

%prep
%autosetup -n grafx2

%build
cd src
make %{?_smp_mflags}

%install
cd src
make install PREFIX=%{_prefix} DESTDIR=%{buildroot}

mkdir -p %{buildroot}%{_datadir}/applications
mkdir -p %{buildroot}%{_datadir}/metainfo

%suse_update_desktop_file grafx2 -r Graphics 2DGraphics

mkdir -p %{buildroot}%{_datadir}/pixmaps
mv %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/grafx2.xpm %{buildroot}%{_datadir}/pixmaps/grafx2.xpm
mv %{buildroot}%{_bindir}/grafx2-sdl %{buildroot}%{_bindir}/grafx2

%files
%{_bindir}/grafx2
%{_datadir}/grafx2
%{_datadir}/applications/grafx2.desktop
%{_datadir}/metainfo/grafx2.appdata.xml
%{_datadir}/pixmaps/grafx2.xpm
%{_datadir}/icons/hicolor/scalable/apps/grafx2.svg

%changelog
* Fri Apr 22 2022 Matthias Mailänder <mailaender@opensuse.org>
- Update to version 2.8.3124
  New Features
  * Load and save SymbOS SGX files
  Improvements
  * Amstrad CPC SCR loading: handle ConvImgCPC packed files
  Fixes
  * Gradient ellipses tool could write pixels outside the image in some cases
  * Fix canvas size when saving GIF files
  * Many fixes to file path handling and unicode support
* Sat Feb  8 2020 Matthias Mailänder <mailaender@opensuse.org>
- Update to version 2.7.2950
  New Features
  * Allow relative directory bookmarks
  * C64 pixcen .GPX format support (loading only)
  * Amiga Extra Half Bright palette support
  * Sega Genesis/Mega Drive drawing mode
  * TMS9918 Mode 2 drawing mode (MSX, ColecoVision, SC-3000, etc.)
  * Load from/save to network neighborhood under windows
  * Support for loading the HP48 GROB format
  * Support for Atari ST TNY format
  * Support for Atari ST CA1 (CrackArt) format
  * Support for Graphos (Amstrad CPC Plus) format
  * Support for loading and saving autoloading C64 picture files
  * Support for loading and saving autoloading CPC picture files
  * Support for MSX Screen 2 pictures (.SC2)
  Improvements
  * keep mouse "captured" in window when the button is pressed
  * Win32: process Horizontal wheel event
  * Add tests to the automatic building process
  * Joystick support rework
  * Nintendo Switch port
  * add support for greek and hiragana/katagana characters in file names
  * many improvements in the documentation
  * build with the latest versions of recoil, lua, libtiff, libjpeg, etc.
  * Packbits optimization (used in IFF, PC1) for smaller files
  * Rotate brush now uses angles from -179° to 180°
  Fixes
  * handling of keyboard mouse emulation + mouse panning
  * Enable to close the application within dialogs
  * properly handle negative mouse coordinates
  * fix memory leaks
  * fix GIF saving (see #125)
  * fix loading of some unusual PNGs
* Thu Aug 29 2019 Xaver Hellauer <xaver@hellauer.bayern>
- Update to version 2.6
  New features:
  * -size option on command line to set the picture size
  * Underline keyboard shortcuts in button labels (easier to use grafx2 with a keyboard)
  * Generic "rasters" drawing mode for CPC
  * Much better support for C64 fileformats (files from various C64 paint programs are recognized and loaded)
  * Load and save Thomson MO/TO pictures (raw files and MAP with some of the well known extensions)
  * Drawing modes that automatically apply constraints of several 8bit computers and consoles (C64 including FLI and Multicoor, ZX now with brightness check, Thomson, Game Boy, Apple II). Auto set palette, grid, etc for ease of use
  * Loading WIN and SCR files from Amstrad CPC, and saving them with palette (separate PAL file in Advanced OCP Art Studio format)
  * Load Apple II HGR and DHGR files
  * Clipboard support: you can copy/paste images and brushes to/from other software in GrafX2 now
  * Load/save TIFF files
  Improvements:
  * Only allow panning when it is safe to do so (not in the middle of a drawing operation)
  * In addition to SDL, support SDL2, Win32 GDI, and X11 backends
  * "tall 3" (1x3 aspect ratio) pixels are properly saved and loaded in GIF files
  * Better management of aspect ratio in PNG files
  * Show the appropriate icon for network drives in the fileselector
  * More system information in the statistics screen
  * Restoring the lasso brush does not erase the current brush if there is nothing to restore
  * URL in inline help are now clickable
  * Mode 5 and raster mode now show ink colors under the cursor in the statusbar
  * Configuring the menu colors in the ini file works again
  * Load a default palette (default.pal) at startup automatically (no need to edit the skin files anymore)
  * Improve loading of Neochrome and IFF images (color cycling, etc)
  * When spare and main pages filename start the same, display the end of the names instead
  * More complete support for BMP files (OS/2 variants, embedded PNG in BMP, etc)
  Fixes:
  * For some operations, the cursor would not be visible or be corrupt
  * Color clash enforcing now works as expected
  * Fix crash when loading images or restoring backups to spare page
  * Saving of CPC images and PI1 images could be corrupt or crash the program
  * Problems with unicode filenames
* Sat Jun  2 2018 aloisio@gmx.com
- Update to version 2.5.1960
  New features:
  * New sample factory scripts: ThomsonConstraints?,
    FontConverter?, CodenetSend?, various picture converters taking
    color clash constraints into account
  * Allow factory scripts full access to our widget/window
    system, for more comple UIs: sliders, textboxes, and more.
  * Android and GCW Zero platforms now supported.
  * New file format: PCH for Amstrad CPC "Perfect Pix" editor
    (load only)
  * Implement saving of palettes in GPL format (GIMP compatible).
  * New 3:4 pixel aspect ratio
  * Gamma-correction of palette
  Fileformats improvements:
  * PI1/PC1 format now can save color cycling information
  * More complete support for IFF files in several formats
  * Better color matching algorithm for C64-multicolor and FLI
    converters.
  * Don't save *.C64 pictures in FLI format, use plain C64
    format instead.
  * Ability to save "fullscreen" CPC/SCR pictures (more than 16K
    of video RAM)
  Scripting improvements:
  * Factory scripts only create a backup step when they actually
    modify the picture
  * matchcolor2 in lua script has better accuracy.
  * API to get the count of layers in main and spare page
  Other improvements:
  * On X11 based platforms (Linux, *BSD), use fontconfig to get
    ttf fonts instead of the X11 API. (issues 305 and 525)
  * Reworked palette look to make the transparent color visible.
  * Right click on "add layer" duplicates the current layer.
  * Added "sort by histogram" in palette editor.
  * Reworked layout of effects and palette windows.
  * Right click on drawing mode button now has a menu to
    directly select the new mode.
  * Animation bar shows total number of frames
  * Limited UTF-8 support
  Fixes:
  * Loading of IFF files from Atari ST version of Deluxe Paint
    (#38)
  * Freeze when palette is vertical and number of rows isn't a
    power of two (issue 539)
  * PC1 files saved in GrafX2 were not loadable in Degas Elite
    (issue 535)
  * Improve choice of colors for the XOR highlight on low-color
    images.
  * Crash when saving CPC pictures in SCR format.
  * Possible crash when opening the file selector.
  * Crash when using contour fill and grid at the same time.
- Spec cleanup
* Sun May 22 2016 mailaender@opensuse.org
- initial packaging of version 2.4.2035
